# Changelog

## [1.1.0] - 2024-02-18
### Added
- Support for Google models

## [0.0.05] - 2024-01-15
### Added
- New feature allowing users to specify model in command line.
- Improved error handling for input validation.
- Fixed partial scan logic
